@@ -17,9 +17,11 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 #include "kgpgitemmodel.h"
-#include "kgpgitemnode.h"
+
 #include "kgpgsettings.h"
-#include "convert.h"
+#include "core/convert.h"
+#include "model/kgpgitemnode.h"
+
 #include <KGlobal>
 #include <KLocale>
 #include <QMetaObject>
@@ -243,6 +245,8 @@ KGpgItemModel::addGroup(const QString &name, const KGpgKeyNode::List &keys)
 	nd = new KGpgGroupNode(m_root, name, keys);
 	endInsertRows();
 
+	nd->saveMembers();
+
 	Q_ASSERT(m_root->getChildIndex(nd) == cIndex);
 
 	return nd;
@@ -293,6 +297,8 @@ KGpgItemModel::changeGroup(KGpgGroupNode *node, const QList<KGpgNode *> &keys)
 		endInsertRows();
 		cnt++;
 	}
+
+	node->saveMembers();
 }
 
 void
@@ -306,6 +312,8 @@ KGpgItemModel::deleteFromGroup(KGpgGroupNode *group, KGpgGroupMemberNode *member
 	beginRemoveRows(pIndex, childRow, childRow);
 	delete member;
 	endRemoveRows();
+
+	group->saveMembers();
 }
 
 QVariant
@@ -343,12 +351,8 @@ KGpgItemModel::setDefaultKey(KGpgKeyNode *def)
 		emit dataChanged(createIndex(odefrow, 0, nd), createIndex(odefrow, lastcol, nd));
 	}
 
-	if (def) {
-		m_default = def->getId();
-		emit dataChanged(createIndex(defrow, 0, def), createIndex(defrow, lastcol, def));
-	} else {
-		m_default.clear();
-	}
+	m_default = def->getId();
+	emit dataChanged(createIndex(defrow, 0, def), createIndex(defrow, lastcol, def));
 }
 
 QModelIndex
@@ -449,7 +453,7 @@ KGpgItemModel::refreshGroups()
 		endRemoveRows();
 	}
 
-	const QStringList groups = KgpgInterface::getGpgGroupNames(KGpgSettings::gpgConfigPath());
+	const QStringList groups = KGpgGroupNode::readGroups();
 
 	if (groups.isEmpty())
 		return;
